"""
Neuber Correction Package

A Python package for performing Neuber correction on stress values
for fatigue life prediction.
"""

from .neuber_correction import NeuberCorrection

__version__ = "0.1.0"
__all__ = ["NeuberCorrection"]
